import type { SuggestedInteraction } from "../mutations"
import type { CombineInteractionDefinition, UseInteractionDefinition } from "../script/types"
import { isEqual } from "lodash-es"

export const getSuggestedInteractionFromDefinition = (definedInteraction: UseInteractionDefinition<any> | CombineInteractionDefinition<any>): SuggestedInteraction => {
    switch (definedInteraction.type) {
        case "use": return { type: "use", objectId: definedInteraction.objectId }
        case "combine": return { type: "combine", objectIds: new Set(definedInteraction.inputObjects.keys()) }
    }
}

export function getSuggestedInteractionId(interaction: SuggestedInteraction) {
    let id: string
    if (interaction.type === "use") id = `use-${interaction.objectId}`
    else if (interaction.type === "combine") id = `combine-${[...interaction.objectIds].sort().join("_")}`
    else throw new Error("Unknown interaction type")
    return id
}

export function findMatchingCombinationInteraction(combinations: Set<CombineInteractionDefinition<any>>, inputItemIds: Set<string>) {
    return combinations.values().find(c => isEqual(new Set(Object.keys(c.inputObjects)), inputItemIds))
}

export type InteractionSceneEvent =
    | { type: "interaction-queued"; interaction: SuggestedInteraction }
    | { type: "votes-changed"; votesByInteractionId: Record<string, number> }
    | { type: "object-visibility-changed"; objectId: string; isVisible: boolean }
    | { type: "object-completion-step-changed"; objectId: string; step: number }
    | { type: "interaction-execution-started"; interaction: SuggestedInteraction }
    | { type: "interaction-execution-finished"; interactionId: string }
    | { type: "interaction-execution-cancelled" }